# Data science for neuroimaging

This library of software accompanies the book "Data science for neuroimaging". It contains utility functions for loading example datasets and some functions to simplify operations that are otherwise long and cumbersome.
